@@ -1,6 +1,4 @@
-from commmons import html, head
-from commmons.hash import md5
-from commmons.url import get_host_url
+from commmons import head, html_from_url, get_host_url, md5
 
 
 def _get_file(a):
@@ -16,6 +14,6 @@ def _get_file(a):
 
 
 def scrape_buondua(url: str):
-    root = html.from_url(url)
+    root = html_from_url(url)
     for a in root.xpath("//a[contains(@class,'item-link')]"):
         yield from _get_file(a)
