@@ -1,10 +1,9 @@
 from commmons import md5, head
-from lxml.html import HtmlElement
 
 from hypersquirrel.util import html_from_url_with_headers
 
 
-def _get_thumb_url(item: HtmlElement) -> str:
+def _get_thumb_url(item) -> str:
     try:
         thumbdiv = head(item.xpath(".//div[@class='thumb']"))
         return thumbdiv.attrib["style"].split("(")[-1].rstrip(");")
