@@ -1,10 +1,10 @@
 import uuid
 
-from commmons import html
+from commmons import html_from_url
 
 
 def scrape_gimg(url):
-    root = html.from_url(url)
+    root = html_from_url(url)
     for img in root.xpath("//img[@src]"):
         yield {
             "fileid": str(uuid.uuid4()),
