@@ -1,5 +1,4 @@
-from commmons import html
-from commmons.url import get_host_url
+from commmons import html_from_url, get_host_url
 
 
 def get_thumbnail_path(element):
@@ -23,7 +22,7 @@ def get_atag(element):
 
 def scrape_hnlg(url):
     host_url = get_host_url(url)
-    root = html.from_url(url)
+    root = html_from_url(url)
 
     for post in root.xpath("//a[contains(@href,'/article/')]"):
         href = post.attrib["href"]
