@@ -1,5 +1,4 @@
-from commmons import html
-from commmons.url import get_host_url
+from commmons import html_from_url, get_host_url
 
 
 def get_title(element):
@@ -19,7 +18,7 @@ def get_thumbnail_path(element):
 
 def scrape_lgbb(url):
     host_url = get_host_url(url)
-    root = html.from_url(url)
+    root = html_from_url(url)
 
     for div in root.xpath("//div[@class='panel panel-default']"):
         title = get_title(div)
