@@ -1,9 +1,8 @@
-from commmons import html
-from commmons.url import get_host_url
+from commmons import html_from_url, get_host_url
 
 
 def scrape(url):
-    tree = html.from_url(url)
+    tree = html_from_url(url)
     host_url = get_host_url(url)
 
     divs = tree.xpath("//div[contains(@class, 'video-item')]")
