@@ -1,5 +1,4 @@
-from commmons import html
-from commmons.url import get_host_url
+from commmons import html_from_url, get_host_url
 
 
 def _get_img(card):
@@ -8,7 +7,7 @@ def _get_img(card):
 
 
 def scrape_v2ph(url):
-    root = html.from_url(url)
+    root = html_from_url(url)
 
     for a in root.xpath("//a[@class='media-cover']"):
         img = _get_img(a)
