@@ -1,4 +1,4 @@
-from commmons import html
+from commmons import html_from_url
 
 
 def get_url_and_filename(root, fileid):
@@ -16,7 +16,7 @@ def get_divs_with_fileid(root):
 
 
 def scrape(url):
-    root = html.from_url(url)
+    root = html_from_url(url)
 
     for div in get_divs_with_fileid(root):
         fileid = div.attrib.get("data-video-id")
